__author__ = 'DarkWeb'

import psycopg2
import traceback
import time
from datetime import date

'''
vendors
add
mk_id
vendor_rating
successful_transactions

products
add
product_rating

remove
date_item
escrow_info
last_viewed
vendor_rating
successful_transaction
'''

def connectDataBase():

    try:

        return psycopg2.connect(host='localhost', user='postgres', password='password', dbname='darkweb_markets_forums')

    except:

        print ("Data base (darkweb_marketplaces) not found.")
        raise SystemExit


def verifyMarketPlace(cur, nameMarket):

    try:

        cur.execute("select id_mk from marketPlaces where name_mk = %(nameMarket)s limit 1", {'nameMarket': nameMarket})

        recset = cur.fetchall()

        if recset:
            return recset[0][0]
        else:
            return 0

    except:

        trace = traceback.format_exc()
        print (trace)


def verifyVendor(cur, nameVendor):

    try:

        cur.execute("select id_ve from vendors where name_ve = %(nameVendor)s limit 1", {'nameVendor': nameVendor})

        recset = cur.fetchall()

        if recset:
            return recset[0][0]
        else:
            return 0

    except:

        trace = traceback.format_exc()
        print (trace)


def getLastMarketPlace(cur):

    try:

        cur.execute("select id_mk from marketPlaces order by id_mk desc limit 1")

        recset = cur.fetchall()

        if recset:
            return recset[0][0]
        else:
            return 0

    except:

        trace = traceback.format_exc()
        print (trace)


def getLastVendor(cur):

    try:

        cur.execute("select id_ve from vendors order by id_ve desc limit 1")

        recset = cur.fetchall()

        if recset:
            return recset[0][0]
        else:
            return 0

    except:

        trace = traceback.format_exc()
        print (trace)


def create_marketPlace(cur, row):

    marketPlace = verifyMarketPlace(cur, row[0])

    if not marketPlace:
       marketPlace = int(getLastMarketPlace(cur) + 1)

       sql = "Insert into marketPlaces (id_mk, name_mk, url_mk, dateInserted) Values (%s, %s, %s, %s)"

       recset = [marketPlace, row[0], None, time.asctime()]

       cur.execute(sql, recset)

    return marketPlace


def create_vendor(cur, row):

    vendor = verifyVendor(cur, row[18])

    if not vendor:
       vendor = int(getLastVendor(cur) + 1)

       sql = "Insert into vendors (id_ve, name_ve, dateInserted) Values (%s, %s, %s)"

       recset = [vendor, row[18], time.asctime()]

       cur.execute(sql, recset)

    return vendor


def create_items(cur, row, marketPlace, vendor):

    sql = "Insert into items (id_mk, id_ve, date_item, name_item, description_item, cve_item, ms_item, category_item, " \
          "escrowinfo_item, views_item, reviews_item, addeddate_item, lastvieweddate_item, btcsellingprice_item, usdsellingprice_item, " \
          "eurosellingprice_item, quantitysold_item, quantityleft_item, shippedfrom_item, shippedto_item, vendorrating, successfulltransactions, " \
          "termsandconditions, dateinserted_item, classification_item) Values (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, " \
          "%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s)"

    recset = [marketPlace, vendor, str("%02d" %date.today().month) + "/" + str("%02d" %date.today().day) + "/" + str("%04d" %date.today().year),
    #recset = [marketPlace, vendor, str("%02d" %date.today().day) + "/" + str("%02d" %date.today().month) + "/" + str("%04d" %date.today().year),
              row[1] if row[1]!= '-1' else None, row[5] if row[5]!= '-1' else None, row[2] if row[2]!= '-1' else None,
              row[3] if row[3]!= '-1' else None, row[4] if row[4]!= '-1' else None, row[6] if row[6]!= '-1' else None,
              row[7] if row[7]!= '-1' else None, row[8] if row[8]!= '-1' else None, row[9] if row[9]!= '-1' else None,
              row[10] if row[10]!= '-1' else None, row[11] if row[11]!= '-1' else None, row[12] if row[12]!= '-1' else None,
              row[13] if row[13]!= '-1' else None, row[14] if row[14]!= '-1' else None, row[15] if row[15]!= '-1' else None,
              row[16] if row[16]!= '-1' else None, row[17] if row[17]!= '-1' else None, row[19] if row[19]!= '-1' else None,
              row[20] if row[20]!= '-1' else None, row[21] if row[21]!= '-1' else None, row[22] if row[22]!= '-1' else None,
              row[24] if row[24]!= '-1' else None]

    cur.execute(sql, recset)


def create_database(cur, con):

    try:

        sql = "create table marketplaces(id_mk integer not null, name_mk character varying(255) not null, " \
              "url_mk character varying(255) null, dateinserted timestamp(6) with time zone not null, " \
              "constraint pk_mk primary key (id_mk))"
        cur.execute(sql)

        sql = "create table vendors(id_ve integer not null, name_ve character varying(255) not null, " \
              "dateinserted timestamp(6) with time zone not null, constraint pk_ve primary key (id_ve))"
        cur.execute(sql)

        sql = "create table items(id_mk integer not null, id_ve integer not null, date_item date not null, name_item character varying(255) not null, " \
              "description_item character varying(1000000) null, cve_item character varying(255) null, ms_item character varying(255) null, " \
              "category_item character varying(255) null, escrowinfo_item character varying(1000) null, views_item integer null, " \
              "reviews_item character varying(255) null, addeddate_item character varying(25) null, " \
              "lastvieweddate_item character varying(25) null, btcsellingprice_item character varying(255) null, " \
              "usdsellingprice_item character varying(255) null, eurosellingprice_item character varying(255) null, quantitysold_item integer null, " \
              "quantityleft_item character varying(255) null, shippedfrom_item character varying(255) null, shippedto_item character varying(5000) null, " \
              "vendorrating character varying(255) null, successfulltransactions character varying(500) null, " \
              "termsandconditions character varying(15000) null, dateinserted_item timestamp(6) with time zone not null, " \
              "classification_item double precision not null, constraint pk_items primary key (id_mk, id_ve, date_item, name_item), " \
              "constraint items_id_mk_fkey foreign key (id_mk) references marketplaces (id_mk),constraint items_id_ve_fkey foreign key (id_ve) references vendors (id_ve))"
        cur.execute(sql)

        con.commit()

    except:

        con.rollback()

        trace = traceback.format_exc()

        if (trace.find("already exists")==-1):
            print ("There was a problem during the database creation." )
            raise SystemExit